@@ -33,12 +33,12 @@ import sys
 from requests.compat import urljoin
 from requests import Request
 from update_checker import update_check
-from warnings import warn_explicit
+from warnings import simplefilter, warn_explicit
 
 from praw import decorators, errors, helpers
 from praw.settings import CONFIG
 
-__version__ = '2.0.10'
+__version__ = '2.0.11'
 UA_STRING = '%%s PRAW/%s Python/%s %s' % (__version__,
                                           sys.version.split()[0],
                                           platform.platform(True))
@@ -48,6 +48,9 @@ MAX_IMAGE_SIZE = 512000
 JPEG_HEADER = '\xff\xd8\xff'
 PNG_HEADER = '\x89\x50\x4e\x47\x0d\x0a\x1a\x0a'
 
+# Enable deprecation warnings
+simplefilter('default')
+
 
 class Config(object):  # pylint: disable-msg=R0903
 
@@ -753,6 +756,10 @@ class AuthenticatedReddit(OAuth2Reddit, UnauthenticatedReddit):
 
         """
         data = {'r': six.text_type(subreddit)}
+        # Clear moderated subreddits and cache
+        # pylint: disable-msg=W0212
+        self.user._mod_subs = None
+        helpers._request.evict([self.config['my_mod_reddits']])
         return self.request_json(self.config['accept_mod_invite'], data=data)
 
     def clear_authentication(self):
@@ -883,6 +890,8 @@ class AuthenticatedReddit(OAuth2Reddit, UnauthenticatedReddit):
         self._authentication = scope
         self.access_token = access_token
         self.refresh_token = refresh_token
+        # pylint: disable-msg=W0212
+        helpers._request.evict([self.config['me']])
         # Update the user object
         if update_user and 'identity' in scope:
             self.user = self.get_me()
